@@ -1,16 +1,24 @@
 import { css, cx } from '@emotion/css';
-import React from 'react';
 
 import { GrafanaTheme } from '@grafana/data';
 import { useStyles } from '@grafana/ui';
 
+import { isValidImageExt } from '../utils/validators';
+
 export interface Props {
   url: string;
   width?: string;
   altText: string;
 }
 
-export const ImagePreview = ({ url, width = '200px', altText }: Props) => {
+const isValidImg = (val: string) => {
+  if (val.startsWith('http')) {
+    return isValidImageExt(val);
+  }
+  return true;
+};
+
+export const ImagePreview = ({ url, altText, width = '200px' }: Props) => {
   const styles = useStyles(getStyles);
   return url ? (
     <div
@@ -21,7 +29,7 @@ export const ImagePreview = ({ url, width = '200px', altText }: Props) => {
         `
       )}
     >
-      <img src={url} className={styles.img} alt={altText} />
+      {isValidImg(url) ? <img src={url} className={styles.img} alt={altText} /> : 'Invalid image'}
     </div>
   ) : null;
 };
